(function (Drupal, $, once) {
  'use strict';

  /**
   * Place warning.
   *
   * @param {HTMLFormElement} form
   */
  function placeWarning(form) {
    const wrapperClass = 'form-change-warning';
    let wrapper = form.querySelector(`.${wrapperClass}`);
    if (!wrapper) {
      wrapper = document.createElement('div');
      wrapper.classList.add(wrapperClass);
      wrapper.innerHTML = Drupal.theme('formValueChangedWarning');
      form.prepend(wrapper);
    }
  }

  Drupal.behaviors.form_change_warning = {
    attach: function (context) {
      once('form_change_warning', 'form').forEach(function (form) {
        $(form).on('change', ':input', function (ev) {
          placeWarning(form);
        });
      });
    }
  };

  $.extend(
    Drupal.theme,
    /** @lends Drupal.theme */ {
      /**
       * @return {string}
       *  Markup for the marker.
       */
      formValueChangedMarker() {
        return `<abbr class="warning formvalue-changed" title="${Drupal.t('Changed')}">*</abbr>`;
      },

      /**
       * @return {string}
       *   Markup for the warning.
       */
      formValueChangedWarning() {
        return `<div class="formvalue-changed-warning messages messages--warning" role="alert">${Drupal.theme(
          'formValueChangedMarker',
        )} ${Drupal.t('You have unsaved changes.')}</div>`;
      },
    }
  );
})(Drupal, jQuery, once);
